.. _design:


Association Design
==================

.. _figure-association-generator-overview:

.. figure:: graphics/overview.png
   :scale: 50%

   Association Generator Overview

As introduced in the :ref:`asn-overview`, the figure above shows all the
major players used in generating associations. Since this section will
be describing the code design, the figure below is the overview but
using the class names involved.

.. _figure-class-overview:

.. figure:: graphics/overview_classes.png
   :scale: 50%

   Association Class Relationship overview
